@@ -10,7 +10,8 @@ user = 'https://users.roblox.com/v1'
 games = 'https://games.roblox.com/v1'
 groups = 'https://groups.roblox.com/v1'
 presence = 'https://presence.roblox.com/v1/presence/users'
-inventory = 'https://inventory.roblox.com/v1/users'
+economy = 'https://economy.roblox.com/v1/assets'
+inventory = 'https://inventory.roblox.com'
 
 
 class BaseAuth:
@@ -25,8 +26,10 @@ class BaseAuth:
         :key proxy_type: Optional: Type (http|https) of the given proxies. Required if using proxies, otherwise optional.
         """
         self.__session = requests.session()
-        self.__cookies, self.__proxies, self.__proxy_type = \
-            data['data'].get('cookies', None), data['data'].get('proxies', None), data['data'].get('proxy_type', None)
+        if data:
+            self.__cookies, self.__proxies, self.__proxy_type = data['data'].get('cookies', None), data['data'].get('proxies', None), data['data'].get('proxy_type', None)
+        else:
+            self.__cookies, self.__proxies, self.__proxy_type = None, None, None
         if self.__cookies:
             if isinstance(self.__cookies, list):
                 pass
@@ -47,7 +50,7 @@ class BaseAuth:
         self.__re = re.compile('https|http')
         if cookie:
             self.__session.cookies['.ROBLOSECURITY'] = cookie
-            self.__session.headers['X-CSRF-TOKEN'] = self.__session.post('https://www.roblox.com/api/item.ashx?').headers['X-CSRF-TOKEN']
+            self.__session.headers['X-CSRF-TOKEN'] = self.__session.post('https://catalog.roblox.com/v1/catalog/items/details').headers['X-CSRF-TOKEN']
             self.__validate_cookie()
 
     def __enter__(self):
